@@ -81,3 +81,16 @@ class Job(DataClassJsonMixin):
 
   creation_time: datetime = datetime.now()
   status: typing.Optional[JobStatus] = None
+
+
+@dataclass
+class Filter(DataClassJsonMixin):
+  id: str
+  user_secret_id: str
+  prompt: str
+  
+  ddim_steps: int
+  scale: float 
+  strength: float
+  
+  creation_time: datetime = datetime.now()
